package com.citygis.web.dataEncrypt.service.impl;


import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.citygis.common.core.domain.AjaxResult;
import com.citygis.web.dataEncrypt.domain.ColumnInfo;
import com.citygis.web.dataEncrypt.domain.JiaMi;
import com.citygis.web.dataEncrypt.domain.RunFile;
import com.citygis.web.dataEncrypt.mapper.JiaMiMapper;
import com.citygis.web.dataEncrypt.service.DataEncryptService;
import com.citygis.web.dataEncrypt.service.JiaMiService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.io.FileInputStream;
import java.security.MessageDigest;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;

@Service
public class JiaMiServiceImpl implements JiaMiService {

    @Resource
    DataEncryptService dataEncryptService;

    @Resource
    JiaMiMapper jiaMiMapper;

    //查询字段值
    @Transactional
    @Override
    public AjaxResult handleEncryption(JiaMi jiaMi) throws Exception {

        List<ColumnInfo> columnList = jiaMiMapper.handleEncryption(jiaMi.getIdColumn(), jiaMi.getTableName(), jiaMi.getColumn());

        int row = 0;
        if (!CollectionUtils.isEmpty(columnList) && columnList.size() > 0) {
            for (ColumnInfo info : columnList) {
                String encryString = dataEncryptService.dataEncrypt(info.getValue());
                row = row + updateEncryption(jiaMi.getIdColumn(), jiaMi.getTableName(), jiaMi.getColumn(), info.getId(), encryString);
            }
        }
        return AjaxResult.success("成功" + row + "行");
    }

    /**
     * 更新字段
     *
     * @param idColumn
     * @param tableName
     * @param column
     * @param id
     * @param encryString
     * @return
     */
    @Transactional
    public int updateEncryption(String idColumn, String tableName, String column, Long id, String encryString) {
        return jiaMiMapper.updateEncryption(idColumn, tableName, column, id, encryString);
    }

    @Transactional
    @Override
    public AjaxResult dataCompleteness(String tableName, String idColumn) {
        List<LinkedHashMap<String, Object>> dateBySql = jiaMiMapper.getData(tableName);

        dateBySql.forEach(map -> {
            StringBuilder text = new StringBuilder();
            map.remove("HAMC_CODE");
            map.remove("IS_ENCRYPT");
            map.forEach((key, value) -> {
                if (text.length() > 0) {
                    text.append(",");
                }
                text.append(value);
            });
            String result = text.toString();
            // 处理 result，如保存到集合或输出
            try {
                String hmacText = dataEncryptService.generateHmac(result);
                jiaMiMapper.updateData(tableName, idColumn, hmacText, map.get(idColumn).toString());
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        });

        return AjaxResult.success("hmac运算：" + dateBySql.size() + "条");
    }

    @Override
    public AjaxResult verifyDataCompleteness(String tableName, String idColumn) {
        List<String> errorData = new ArrayList<>();

        List<LinkedHashMap<String, Object>> dateBySql = jiaMiMapper.getVerifyData(tableName);
        dateBySql.forEach(map -> {
            StringBuilder text = new StringBuilder();
            String hamcCode = map.get("HAMC_CODE").toString();
            map.remove("HAMC_CODE");
            map.remove("IS_ENCRYPT");
            map.forEach((key, value) -> {
                if (text.length() > 0) {
                    text.append(",");
                }
                text.append(value);
            });
            String result = text.toString();
            // 处理 result，如保存到集合或输出
            try {
                String hmacText = dataEncryptService.generateHmac(result);
                if (!hmacText.equals(hamcCode)) {
                    errorData.add(map.get(idColumn).toString());
                }
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        });
        return AjaxResult.success("验证运算：" + dateBySql.size() + "条，错误数据：" + errorData.size() + "条,id为--->", errorData);
    }

    @Transactional
    @Override
    public AjaxResult fileSign() {
        List<RunFile> runFilePath = jiaMiMapper.getRunFilePath();
        runFilePath.forEach(runFile -> {
            String fileHash = getFileHash(runFile.getFilePath());
            try {
                String hmacText = dataEncryptService.generateHmac(fileHash);
                runFile.setSignCode(hmacText);
                jiaMiMapper.updateSignCode(runFile);
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        });
        return AjaxResult.success("文件签名：" + runFilePath.size() + "条");
    }

    @Override
    public AjaxResult verifyFileSign(Integer id) {
        List<String> filePath = new ArrayList<>();
        List<RunFile> runFilePath = jiaMiMapper.getVerifyRunFilePath(id);
        runFilePath.forEach(runFile -> {
            String fileHash = getFileHash(runFile.getFilePath());
            try {
                String hmacText = dataEncryptService.generateHmac(fileHash);
                if (!hmacText.equals(runFile.getSignCode())) {
                    filePath.add(runFile.getFilePath());
                }
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
        });
        return AjaxResult.success("文件验证签名：" + runFilePath.size() + "条，错误文件：" + filePath.size() + "条,文件路径为--->", filePath);
    }

    @Transactional
    @Override
    public AjaxResult anewFileSign(Integer id) {
        List<RunFile> verifyRunFilePath = jiaMiMapper.getVerifyRunFilePath(id);
        verifyRunFilePath.forEach(runFile -> {
            String fileHash = getFileHash(runFile.getFilePath());
            try {
                String hmacText = dataEncryptService.generateHmac(fileHash);
                runFile.setSignCode(hmacText);
                jiaMiMapper.updateSignCode(runFile);
            }catch (Exception e) {
                throw new RuntimeException(e);
            }
        });
        return AjaxResult.success("文件签名：" + verifyRunFilePath.size() + "条");
    }

    /**
     * 获取文件hash
     *
     * @param path
     * @return
     */
    public String getFileHash(String path) {

        StringBuffer sb = new StringBuffer();
        try {
            MessageDigest md = MessageDigest.getInstance("MD5");
            FileInputStream fis = new FileInputStream(path);
            byte[] buff = new byte[8192];
            int length;
            while ((length = fis.read(buff)) != -1) {
                md.update(buff, 0, length);
            }
            fis.close();
            byte[] digest = md.digest();

            for (byte b : digest) {
                sb.append(String.format("%02x", b));
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

        return sb.toString();
    }

}
