package com.citygis.web.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.citygis.common.annotation.Excel;
import com.citygis.common.core.domain.BaseEntity;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.List;

/**
 * <p>
 * 接入配置
 * </p>
 *
 * @author citygis
 * @since 2025-01-02
 */
@Data
@EqualsAndHashCode(callSuper = false)
@TableName("TAB_ACCESS_CONFIG")
@ApiModel(value = "TabAccessConfig对象", description = "接入配置")
public class TabAccessConfig extends BaseEntity implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "id")
    @TableField("ID")
    @TableId(value = "ID", type = IdType.ASSIGN_ID)
    @JsonSerialize(using = ToStringSerializer.class)
    private Long id;

    @ApiModelProperty(value = "id数组")
    @TableField(exist = false)
    private List<Long> ids;

    @ApiModelProperty(value = "六统一ip")
    @TableField("SIX_IP")
    @Excel(name = "六统一ip")
    private String sixIp;

    @ApiModelProperty(value = "六统一端口")
    @TableField("SIX_PORT")
    @Excel(name = "六统一端口")
    private String sixPort;

    @ApiModelProperty(value = "网关ip")
    @TableField("GATEWAY_IP")
    @Excel(name = "网关ip")
    private String gatewayIp;

    @ApiModelProperty(value = "网管端口")
    @TableField("GATEWAY_PORT")
    @Excel(name = "网管端口")
    private String gatewayPort;

    @ApiModelProperty(value = "数据提供方所属信息系统")
    @TableField("OFFER_SYSTEM")
    @Excel(name = "数据提供方所属信息系统")
    private String offerSystem;

    @ApiModelProperty(value = "数据接收方所属信息系统")
    @TableField("RECEPTION_SYSTEM")
    @Excel(name = "数据接收方所属信息系统")
    private String receptionSystem;

    @ApiModelProperty(value = "数据资源信息")
    @TableField("DATA_DETAIL")
    @Excel(name = "数据资源信息")
    private String dataDetail;

    @ApiModelProperty(value = "拟/正式运行时间")
    @TableField("RUN_TIME")
    @Excel(name = "拟/正式运行时间", dateFormat = "yyyy-MM-dd HH:mm:ss")
    private String runTime;

    @ApiModelProperty(value = "状态:0停用，1启用")
    @TableField("STATUS")
    @Excel(name = "状态",readConverterExp = "0=停用,1=启用")
    private Integer status;

    @ApiModelProperty(value = "数据接入方式")
    @TableField("DATA_MANNER")
    @Excel(name = "数据接入方式")
    private String dataManner;

    @ApiModelProperty(value = "是否删除：0未删除，1删除")
    @TableField("IS_DEL")
    private Integer isDel;

    @ApiModelProperty(value = "是否启用：0未启动，1启用")
    @TableField("IS_APPLY")
    @Excel(name = "是否启用：0未启动，1启用",readConverterExp = "0=未启用,1=启用")
    private Integer isApply;

    @ApiModelProperty(value = "创建人id")
    @TableField("USER_ID")
    private Long userId;

    @ApiModelProperty(value = "创建人部门id")
    @TableField("DEPT_ID")
    private Long deptId;


}
